/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.io.IOException;
import java.util.List;
import java.util.regex.Pattern;
import javax.xml.parsers.ParserConfigurationException;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import nl.cloudfarming.client.isobus.model.Grid;
import nl.cloudfarming.client.isobus.model.IsobusTask;
import nl.cloudfarming.client.isobus.model.TreatmentZone;
import org.openide.filesystems.FileObject;
import org.openide.loaders.*;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;
import org.xml.sax.SAXException;

public class GridDataObject extends MultiDataObject {

    private IsobusRaster raster;
    public static final String MIME_TYPE = "application/x-grid";
    private List<TreatmentZone> treatmentZones = null;
    private Grid grid = null;
    private FileObject pf;

    public GridDataObject(FileObject pf, MultiFileLoader loader, List<FileObject> secondary) throws DataObjectExistsException, IOException, ParserConfigurationException, SAXException {
        super(pf, loader);
        registerEditor(MIME_TYPE, true);
        this.pf = pf;

        setSecondaryFiles(secondary);
        
        GridReader reader = new GridReader();
        Pattern taskDataPattern = Pattern.compile(GridFileLoader.TASKDATA_PATTERN);
        for (Entry entry : secondaryEntries()) {
            FileObject child = entry.getFile();
            if (taskDataPattern.matcher(child.getNameExt()).find()) {
                IsobusDataObject isobusDataObject = (IsobusDataObject) DataObject.find(child);
                for (IsobusTask task : isobusDataObject.getIsobusTaskData().getTSK()) {
                    if (task.getGRD() != null && task.getGRD().getFilename() != null && task.getGRD().getFilename().toLowerCase().equals(pf.getName().toLowerCase())) {
                        grid = task.getGRD();
                        treatmentZones = reader.getTreatMentZones(pf, task.getTZN());
                    }
                }
            }
        }
    }
    
    /** 
     * Provides node that should represent this data object.
    *
    * @return the node representation
    * @see DataNode
    */
    @Override
    protected Node createNodeDelegate () {
        if (associateLookup() >= 1) {
            DataNode node = new DataNode(this, Children.LEAF, new ProxyLookup(getLookup(), Lookups.fixed(new SimpleLayer(pf.getName()), getIsobusRaster())));
            node.setIconBaseWithExtension("nl/cloudfarming/client/isobus/type/isobus_taskdata_grid.png");
            return node;
        }
        DataNode dataNode = (DataNode) super.createNodeDelegate ();
        return dataNode;
    }

    @Override
    protected int associateLookup() {
        return 1;
    }

    public IsobusRaster getIsobusRaster() {
        if (raster == null) {
            if(grid != null){
                raster = new IsobusRaster(grid, treatmentZones);
            } 
        }
        return raster;

    }

    /**
     * Method to set the secondary files
     *
     * @param secondary the secondary files
     */
    private void setSecondaryFiles(List<FileObject> secondary) {
        for (FileObject fileObject : secondary) {
            registerEntry(fileObject);
        }
    }
}
