/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.io.IOException;
import nl.cloudfarming.client.isobus.model.IsobusTaskData;
import nl.cloudfarming.client.isobus.model.IsobusUnMarshaller;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.text.MultiViewEditorElement;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

public class IsobusDataObject extends MultiDataObject {

    private IsobusTaskData isobusTaskData;
    
    public IsobusDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        
        
        registerEditor("text/isobus+xml", true);
        isobusTaskData = new IsobusUnMarshaller().unMarshall(pf);
    }

    @Override
    protected Node createNodeDelegate() {
        //FIXME quick workaround for AGROSENSE-582, investigate and apply proper fix
        if (isobusTaskData != null){
            return new TaskDataRootNode(isobusTaskData, super.createNodeDelegate());
        }else{
            return super.createNodeDelegate();
        }
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.isobus.project.explorer");
    }
    
    public IsobusTaskData getIsobusTaskData(){
        return isobusTaskData;       
    }
    
    @Override
    protected int associateLookup() {
        return 1;
    }

    @MultiViewElement.Registration(displayName = "#LBL_Isobus_EDITOR",
    iconBase = "nl/cloudfarming/client/isobus/project/iso16.png",
    mimeType = "text/isobus+xml",
    persistenceType = TopComponent.PERSISTENCE_ONLY_OPENED,
    preferredID = "Isobus",
    position = 1000)
    @Messages("LBL_Isobus_EDITOR=Source")
    public static MultiViewEditorElement createEditor(Lookup lkp) {
        return new MultiViewEditorElement(lkp);
    }
}
