/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.type;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;
import java.util.List;
import java.util.concurrent.Callable;
import nl.cloudfarming.client.geoviewer.Geographical;
import nl.cloudfarming.client.isobus.model.Grid;
import nl.cloudfarming.client.isobus.model.TreatmentZone;
import org.geotools.coverage.grid.GridCoverage2D;
import org.geotools.geometry.jts.JTSFactoryFinder;

/**
 * A grid for isobus GRD[0-9][0-9[0-9[0-9[0-9.bin files
 * @author Merijn Zengers
 */
public class IsobusRaster extends nl.cloudfarming.client.geoviewer.Grid {

    private Grid grid;
    private List<TreatmentZone> treatmentZones;
    
    /**
     * Constructs a IsobusRaster object
     * Needs a grid object to get the grid properties from
     * Needs a list of treatment zones to fill the grid with 
     * Take note:! the order of the list of treatMentzones is important
     * assumes the order is the same as in which it is read from the GRD[0-9][0-9[0-9[0-9[0-9.bin file
     * starting at the left bottom of the grid and ending at the right top
     * @param grid the grid to Create a raster for
     * @param treatmentZones the treatmentZones to fill the raster with
     */
    public IsobusRaster(final Grid grid, final List<TreatmentZone> treatmentZones){
        super(new Callable<GridCoverage2D>() {

            @Override
            public GridCoverage2D call() throws Exception {
                return RasterFactory.createRaster(grid, treatmentZones);
            }
        });
        this.grid = grid;
        this.treatmentZones = treatmentZones;
    }


    @Override
    public String getTooltipText() {
        return "";
    }

    @Override
    public long getId() {
        return 1l;
    }
   
}
