/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus.type;

import java.util.List;
import nl.cloudfarming.client.isobus.model.IsobusLineString;
import nl.cloudfarming.client.isobus.model.IsobusPoint;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * @author Gerben Feenstra
 */
@Messages("isobus.project.taskdata.node.name.point=Point ({0}, {1})")
public class LineStringChildFactory extends ChildFactory<IsobusPoint> {

    private static final String POINT_NODE_ICON = "";
    private final IsobusLineString lineString;

    public LineStringChildFactory(IsobusLineString lineString) {
        this.lineString = lineString;
    }
    
    @Override
    protected boolean createKeys(List<IsobusPoint> toPopulate) {
        toPopulate.addAll(lineString.getPoints());
        return true;
    }

    @Override
    protected Node createNodeForKey(IsobusPoint point) {
        String displayName = NbBundle.getMessage(LineStringChildFactory.class, "isobus.project.taskdata.node.name.point", point.getPositionEast(), point.getPositionNorth());
        return new IsobusCommonNode(Children.LEAF, point, POINT_NODE_ICON, displayName);
    }
}
